@@ -2,5 +2,4 @@
 from redscope.features.schema_introspection.db_introspection import introspect_constraints, introspect_users, \
     introspect_tables, introspect_views, introspect_db, introspect_groups, introspect_schemas, introspect_user_groups
 
-from redscope.env import load_redscope_env
-from redscope.database.db_connections import get_db_connection
+from redscope.terminal.tools.entry import load_redscope_env, get_db_connection
