@@ -5,7 +5,8 @@ SELECT ns.nspname AS schema_name,
        a.attnum AS column_order,
        format_type(a.atttypid, a.atttypmod) AS data_type,
        CASE WHEN  ad.adsrc  IS NOT NULL THEN 'DEFAULT ' ||  ad.adsrc ELSE '' END AS default_value,
-       CASE WHEN a.attnotnull IS TRUE THEN 'NOT NULL' ELSE '' END AS not_null
+       CASE WHEN a.attnotnull IS TRUE THEN 'NOT NULL' ELSE '' END AS not_null,
+       CASE format_encoding(a.attencodingtype) WHEN 'none' THEN 'ENCODE RAW' ELSE 'ENCODE ' + format_encoding(a.attencodingtype) END as encoding
   FROM pg_namespace ns
        INNER JOIN pg_class c
           ON ns.oid = c.relnamespace
